# Generated by Django 3.1.14 on 2022-05-06 16:49

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('dubletten_tool', '0006_statusbuttongroup_statusbuttongrouptype_statusbuttonproxy_statusbuttonproxytype'),
    ]

    operations = [
        migrations.AlterField(
            model_name='statusbuttongroup',
            name='related_instance',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='dubletten_tool.group'),
        ),
        migrations.AlterField(
            model_name='statusbuttonproxy',
            name='related_instance',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='dubletten_tool.personproxy'),
        ),
    ]
