# Generated by Django 3.1.14 on 2022-05-10 07:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dubletten_tool', '0010_auto_20220510_0611'),
    ]

    operations = [
        migrations.AlterField(
            model_name='group',
            name='note',
            field=models.TextField(blank=True, max_length=2000, null=True),
        ),
        migrations.AlterField(
            model_name='personproxy',
            name='note',
            field=models.TextField(blank=True, max_length=2000, null=True),
        ),
        migrations.DeleteModel(
            name='Note',
        ),
    ]
