<div class="container-fluid">
    <h4>{{name}} [{{instance.id}}]</h4>
    <pre>{{note}}</pre>
    <span class="d-flex justify-content-start align-items-center"></span><button class="btn btn-outline-secondary" onclick="editNote('{{instance.id}}','{{type}}' )"><i class="fa fa-edit"></i></button>
    </span>
</div>