# Generated by Django 3.1.14 on 2022-04-30 01:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('dubletten_tool', '0003_auto_20220430_0140'),
    ]

    operations = [
        migrations.RenameField(
            model_name='personproxy',
            old_name='first_names',
            new_name='_first_names',
        ),
        migrations.RenameField(
            model_name='personproxy',
            old_name='names',
            new_name='_names',
        ),
    ]
