# Generated by Django 3.1.14 on 2022-04-30 01:31

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dubletten_tool', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='group',
            options={'ordering': ['name']},
        ),
        migrations.AlterModelOptions(
            name='personproxy',
            options={'ordering': ['person__name']},
        ),
        migrations.AddField(
            model_name='personproxy',
            name='_names',
            field=models.JSONField(blank=True, null=True),
        ),
    ]
