# Generated by Django 3.1.14 on 2022-05-09 09:04

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('dubletten_tool', '0008_group__gender'),
    ]

    operations = [
        migrations.CreateModel(
            name='Note',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField(blank=True, max_length=2000, null=True)),
            ],
        ),
        migrations.AddField(
            model_name='group',
            name='marked',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='personproxy',
            name='marked',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='group',
            name='note',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='dubletten_tool.note'),
        ),
        migrations.AddField(
            model_name='personproxy',
            name='notes',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='dubletten_tool.note'),
        ),
    ]
