
<div class="container-fluid m-0 mt-3 p-0">

<ul class="list-group" id="all_groups_list">
    {% for g in groups %}
    <!-- DISPLAY EACH GROUP: ID - Name - Count -->
    <li class="list-group-item group_list_item_ list-group-item-sm d-flex justify-content-between align-items-center left_group_list_item" onclick="toggleItemSelect('{{g.id}}')" id="li_group_{{g.id}}">{{g.id}} {{g.name}}
    <span class="badge badge-primary badge-pill" id="group_count_badge_{{g.id}}">{{g.count}}</span> </li>
    {% endfor %}
</ul>
</div>