# Generated by Django 3.1.14 on 2022-05-09 08:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dubletten_tool', '0007_auto_20220506_1649'),
    ]

    operations = [
        migrations.AddField(
            model_name='group',
            name='_gender',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
