# Generated by Django 3.1.14 on 2022-04-30 01:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dubletten_tool', '0002_auto_20220430_0131'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='personproxy',
            name='_names',
        ),
        migrations.AddField(
            model_name='personproxy',
            name='first_names',
            field=models.JSONField(null=True),
        ),
        migrations.AddField(
            model_name='personproxy',
            name='names',
            field=models.JSONField(null=True),
        ),
    ]
