# Generated by Django 3.1.14 on 2022-04-30 18:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dubletten_tool', '0004_auto_20220430_0148'),
    ]

    operations = [
        migrations.CreateModel(
            name='Suggestions',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('data', models.JSONField(blank=True, null=True)),
            ],
        ),
    ]
