# Generated by Django 3.1.14 on 2022-05-06 10:58

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('dubletten_tool', '0005_suggestions'),
    ]

    operations = [
        migrations.CreateModel(
            name='StatusButtonGroupType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=600)),
            ],
        ),
        migrations.CreateModel(
            name='StatusButtonProxyType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=600)),
            ],
        ),
        migrations.CreateModel(
            name='StatusButtonProxy',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.BooleanField(default=False)),
                ('kind', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='dubletten_tool.statusbuttonproxytype')),
                ('related_instance', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='dubletten_tool.personproxy')),
            ],
        ),
        migrations.CreateModel(
            name='StatusButtonGroup',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('value', models.BooleanField(default=False)),
                ('kind', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='dubletten_tool.statusbuttongrouptype')),
                ('related_instance', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to='dubletten_tool.group')),
            ],
        ),
    ]
