# Generated by Django 3.1.14 on 2022-05-10 06:11

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('dubletten_tool', '0009_auto_20220509_0904'),
    ]

    operations = [
        migrations.RenameField(
            model_name='personproxy',
            old_name='notes',
            new_name='note',
        ),
    ]
